Package: reshape
Version: 0.8.10
Title: Flexibly Reshape Data
Description: Flexibly restructure and aggregate data using 
  just two functions: melt and cast.
Authors@R: 
    person("Hadley", "Wickham", , "hadley@rstudio.com", c("aut", "cre"))
URL: http://had.co.nz/reshape
Depends: R (>= 2.6.1)
Imports: plyr
License: MIT + file LICENSE
LazyData: true
NeedsCompilation: no
Packaged: 2025-06-19 14:50:44 UTC; hadleywickham
Author: Hadley Wickham [aut, cre]
Maintainer: Hadley Wickham <hadley@rstudio.com>
Repository: CRAN
Date/Publication: 2025-06-19 15:40:06 UTC
Built: R 4.6.0; ; 2026-04-25 16:08:06 UTC; unix
