exportPattern("^[^\\.]")
import(plyr)

importFrom("stats", "complete.cases", "mad", "median", "sd")
importFrom("utils", "str", "type.convert")

S3method(as.data.frame,cast_df)
S3method(as.data.frame,cast_matrix)
S3method(as.matrix,cast_df)
S3method(as.matrix,cast_matrix)
S3method(colsplit,character)
S3method(colsplit,factor)
S3method(melt,array)
S3method(melt,cast_df)
S3method(melt,cast_matrix)
S3method(melt,data.frame)
S3method(melt,default)
S3method(melt,list)
S3method(melt,matrix)
S3method(melt,table)
S3method(print,cast_df)
S3method(print,cast_matrix)
S3method(rescaler,data.frame)
S3method(rescaler,default)
S3method(rescaler,matrix)
S3method(str,cast_df)
S3method(str,cast_matrix)
