\name{tidystamp}
\alias{tidystamp}
\title{Tidy up stamped data set}
\author{Hadley Wickham <h.wickham@gmail.com>}

\description{
@keyword internal
}
\usage{tidystamp(x)}
\arguments{
\item{x}{}
}


\keyword{internal}
