\name{Smiths}
\docType{data}
\alias{smiths}
\title{Demo data describing the Smiths}
\description{

A small demo dataset describing John and Mary Smith.  Used in the introductory vignette.

}
\usage{data(smiths)}
\format{A data frame with 2 rows and 5 variables}
\keyword{datasets}
