\name{melt.default}
\alias{melt.default}
\title{Default melt function}
\author{Hadley Wickham <h.wickham@gmail.com>}

\description{
For vectors, make a column of a data frame
}
\usage{\method{melt}{default}(data, ...)}
\arguments{
\item{data}{data frame}
\item{...}{arguments}
}


\keyword{internal}
