\name{sort_df}
\alias{sort_df}
\title{Sort data frame}
\author{Hadley Wickham <h.wickham@gmail.com>}

\description{
Convenience method for sorting a data frame using the given variables.
}
\usage{sort_df(data, vars=names(data))}
\arguments{
\item{data}{data frame to sort}
\item{vars}{variables to use for sorting}
}

\details{Simple wrapper around order}

\keyword{manip}
