\name{merge_recurse}
\alias{merge_recurse}
\title{Merge recursively}
\author{Hadley Wickham <h.wickham@gmail.com>}

\description{
Recursively merge data frames
}
\usage{merge_recurse(dfs, ...)}
\arguments{
\item{dfs}{list of data frames to merge}
\item{...}{}
}

\seealso{\code{\link{merge_all}}}
\keyword{internal}
