\name{add.missing.levels}
\alias{add.missing.levels}
\title{Add in any missing values}
\author{Hadley Wickham <h.wickham@gmail.com>}

\description{
@keyword internal
}
\usage{add.missing.levels(data, vars=NULL, fill=NA)}
\arguments{
\item{data}{}
\item{vars}{}
\item{fill}{}
}


\keyword{internal}
